KVideoPlayer class

Inheritance

Constructors

KVideoPlayer({Key? key, Color? themeColor, String? path, String? url, VideoPlayerController? controller, bool autoPlay = false, bool loop = false, bool showBack = false, bool showFullScreen = true})
const

Properties

autoPlay bool
Whether to play the video automatically after initializing. Defaults to false.
final
controller → VideoPlayerController?
Assign the video player controller while switching to fullscreen mode
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loop bool
Whether to play the video in loop after completion. Defaults to false.
final
path String?
Local video path that is picked from storage or stored in cache
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showBack bool
Set to true while switching to fullscreen mode. Defaults to false.
final
showFullScreen bool
Set to false while switching to fullscreen mode. Defaults to true.
final
themeColor Color?
The theme color of the will be used across the player.
final
url String?
Video url
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<KVideoPlayer>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited