KVideoPlayerContols class

Inheritance

Constructors

KVideoPlayerContols({Key? key, required VideoPlayerController controller, required bool showBack, required bool showFullScreen, Color? themeColor, required double aspectRatio, required dynamic onAspectRatioChanged(double)})
const

Properties

aspectRatio double
The aspect ratio of the video player.required
final
controller → VideoPlayerController
Assign the video player controller to handle the controls required
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onAspectRatioChanged → dynamic Function(double)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showBack bool
Set to true while switching to fullscreen mode. required
final
showFullScreen bool
Set to false while switching to fullscreen mode.required
final
themeColor Color?
The theme color of the will be used across the player.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<KVideoPlayerContols>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited