controller property
VideoPlayerController
controller
final
Assign the video player controller to handle the controls required
Implementation
final VideoPlayerController controller;
Assign the video player controller to handle the controls required
final VideoPlayerController controller;